extends Node2D

const PLAYER_SPEED := 256.0
const ENEMY_SPEED := 512.0

var is_player_moving := false
var is_enemy_moving := false
var is_colliding := false

onready var player: KinematicBody2D = $Player
onready var enemy: Area2D = $Enemy
onready var distance_label := $CanvasLayer/Label
onready var colliding_ui: ColorRect = $CanvasLayer/ColorRect

onready var player_reset_position: Vector2 = $Player.global_position
onready var enemy_reset_position: Vector2 = $Enemy.global_position


func _input(event: InputEvent):
    if event is InputEventKey and event.is_pressed():
        match event.scancode:
            KEY_Q:
                is_player_moving = not is_player_moving
            KEY_W:
                is_enemy_moving = not is_enemy_moving
            KEY_R:
                player.global_position = player_reset_position
                enemy.global_position = enemy_reset_position


func _physics_process(delta: float):
    if is_player_moving: 
        # warning-ignore: return_value_discarded
        player.move_and_collide(PLAYER_SPEED * Vector2.RIGHT * delta)

    if is_enemy_moving:
        enemy.global_position += ENEMY_SPEED * Vector2.RIGHT * delta

    is_colliding = enemy.overlaps_body(player)


func _process(_delta: float):
    var player_distance := player.global_position.distance_to(enemy.global_position)
    distance_label.text = "Distance from player: %.2f" % player_distance

    colliding_ui.color = Color.green if is_colliding else Color.red
